@@ -174,6 +174,7 @@ module Test.SmallCheck.Series (
   decDepth,
   getDepth,
   generate,
+  listSeries,
   list,
   listM,
   fixDepth,
@@ -228,8 +229,26 @@ generate f = do
 suchThat :: Series m a -> (a -> Bool) -> Series m a
 suchThat s p = s >>= \x -> if p x then pure x else empty
 
+-- | Given a depth, return the list of values generated by a Serial instance.
+--
+-- Example, list all integers up to depth 1:
+--
+-- * @listSeries 1 :: [Int]   -- returns [0,1,-1]@
+listSeries :: Serial Identity a => Depth -> [a]
+listSeries d = list d series
+
 -- | Return the list of values generated by a 'Series'. Useful for
 -- debugging 'Serial' instances.
+--
+-- Examples:
+--
+-- * @list 3 'series' :: [Int]                  -- returns [0,1,-1,2,-2,3,-3]@
+--
+-- * @list 3 ('series' :: 'Series' 'Identity' Int)  -- returns [0,1,-1,2,-2,3,-3]@
+--
+-- * @list 2 'series' :: [[Bool]]               -- returns [[],[True],[False]]@
+--
+-- The first two are equivalent. The second has a more explicit type binding.
 list :: Depth -> Series Identity a -> [a]
 list d s = runIdentity $ observeAllT $ runSeries d s
 
